import { __extends } from "tslib";
import { randomAddress, assign } from "../../utils";
import { HubPoolClient } from "../HubPoolClient";
import { getEventManager } from "./MockEvents";
var emptyRootBundle = {
    poolRebalanceRoot: "",
    relayerRefundRoot: "",
    slowRelayRoot: "",
    proposer: "",
    unclaimedPoolRebalanceLeafCount: 0,
    challengePeriodEndTimestamp: 0,
    bundleEvaluationBlockNumbers: [],
    proposalBlockNumber: undefined,
};
var MockHubPoolClient = /** @class */ (function (_super) {
    __extends(MockHubPoolClient, _super);
    function MockHubPoolClient(logger, hubPool, configStoreClient, deploymentBlock, chainId) {
        if (deploymentBlock === void 0) { deploymentBlock = 0; }
        if (chainId === void 0) { chainId = 1; }
        var _this = _super.call(this, logger, hubPool, configStoreClient, deploymentBlock, chainId) || this;
        _this.rootBundleProposal = emptyRootBundle;
        _this.events = [];
        _this.l1TokensMock = []; // L1Tokens and their associated info.
        _this.tokenInfoToReturn = { address: "", decimals: 0, symbol: "" };
        _this.l1TokensToDestinationTokensMock = {};
        _this.returnedL1TokenForDeposit = "";
        _this.returnedDestinationTokenForL1Token = "";
        _this.eventSignatures = {
            SetEnableDepositRoute: "uint256,uint256,address,bool",
            SetPoolRebalanceRoute: "uint256,address,address",
            ProposeRootBundle: "uint32,uint8,uint256[],bytes32,bytes32,bytes32,address",
            RootBundleExecuted: "uint256,uint256,uint256,address[],uint256[],int256[],int256[],address",
        };
        _this.eventManager = getEventManager(chainId, _this.eventSignatures, deploymentBlock);
        return _this;
    }
    MockHubPoolClient.prototype.setCrossChainContracts = function (chainId, contract, blockNumber) {
        if (blockNumber === void 0) { blockNumber = 0; }
        assign(this.crossChainContracts, [chainId], [
            {
                spokePool: contract,
                blockNumber: blockNumber,
                transactionIndex: 0,
                logIndex: 0,
            },
        ]);
    };
    MockHubPoolClient.prototype.setLatestBlockNumber = function (blockNumber) {
        this.latestBlockNumber = blockNumber;
    };
    MockHubPoolClient.prototype.addEvent = function (event) {
        this.events.push(event);
    };
    MockHubPoolClient.prototype.addL1Token = function (l1Token) {
        this.l1TokensMock.push(l1Token);
    };
    MockHubPoolClient.prototype.getL1Tokens = function () {
        return this.l1TokensMock;
    };
    MockHubPoolClient.prototype.getTokenInfoForDeposit = function () {
        return this.tokenInfoToReturn;
    };
    MockHubPoolClient.prototype.getTokenInfoForL1Token = function (l1Token) {
        return this.l1TokensMock.find(function (token) { return token.address === l1Token; });
    };
    MockHubPoolClient.prototype.setTokenInfoToReturn = function (tokenInfo) {
        this.tokenInfoToReturn = tokenInfo;
    };
    MockHubPoolClient.prototype.setL1TokensToDestinationTokens = function (l1TokensToDestinationTokens) {
        this.l1TokensToDestinationTokensMock = l1TokensToDestinationTokens;
    };
    MockHubPoolClient.prototype.getDestinationTokenForL1Token = function (l1Token, destinationChainId) {
        var _a, _b, _c;
        return ((_c = (_b = (_a = this.l1TokensToDestinationTokensMock[l1Token]) === null || _a === void 0 ? void 0 : _a[destinationChainId]) !== null && _b !== void 0 ? _b : this.returnedDestinationTokenForL1Token) !== null && _c !== void 0 ? _c : _super.prototype.getDestinationTokenForL1Token.call(this, l1Token, destinationChainId));
    };
    MockHubPoolClient.prototype.setReturnedL1TokenForDeposit = function (l1Token) {
        this.returnedL1TokenForDeposit = l1Token;
    };
    MockHubPoolClient.prototype.setDestinationTokenForL1Token = function (destinationToken) {
        this.returnedDestinationTokenForL1Token = destinationToken;
    };
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    MockHubPoolClient.prototype.getL1TokenForDeposit = function (_deposit) {
        var _a;
        return (_a = this.returnedL1TokenForDeposit) !== null && _a !== void 0 ? _a : _super.prototype.getL1TokenForDeposit.call(this, _deposit);
    };
    MockHubPoolClient.prototype.getL1TokenCounterpartAtBlock = function (l2ChainId, l2Token, hubPoolBlock) {
        var _a;
        return (_a = this.returnedL1TokenForDeposit) !== null && _a !== void 0 ? _a : _super.prototype.getL1TokenCounterpartAtBlock.call(this, l2ChainId, l2Token, hubPoolBlock);
    };
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    MockHubPoolClient.prototype.getL1TokenInfoForL2Token = function (l2Token, _chain) {
        var _a;
        return (_a = this.getTokenInfoForL1Token(l2Token)) !== null && _a !== void 0 ? _a : this.tokenInfoToReturn;
    };
    MockHubPoolClient.prototype._update = function (eventNames) {
        // Generate new "on chain" responses.
        var latestBlockNumber = this.eventManager.blockNumber;
        var currentTime = Math.floor(Date.now() / 1000);
        // Ensure an array for every requested event exists, in the requested order.
        // All requested event types must be populated in the array (even if empty).
        var _events = eventNames.map(function () { return []; });
        this.events.flat().forEach(function (event) {
            var idx = eventNames.indexOf(event.event);
            if (idx !== -1) {
                _events[idx].push(event);
            }
        });
        this.events = [];
        // Transform 2d-events array into a record.
        var events = Object.fromEntries(eventNames.map(function (eventName, idx) { return [eventName, _events[idx]]; }));
        return Promise.resolve({
            success: true,
            currentTime: currentTime,
            latestBlockNumber: latestBlockNumber,
            pendingRootBundleProposal: this.rootBundleProposal,
            events: events,
            searchEndBlock: this.eventSearchConfig.toBlock || latestBlockNumber,
        });
    };
    MockHubPoolClient.prototype.setPoolRebalanceRoute = function (destinationChainId, l1Token, destinationToken) {
        var event = "SetPoolRebalanceRoute";
        var topics = [destinationChainId, l1Token, destinationToken];
        var args = {
            destinationChainId: destinationChainId,
            l1Token: l1Token,
            destinationToken: destinationToken,
        };
        return this.eventManager.generateEvent({
            event: event,
            address: this.hubPool.address,
            topics: topics.map(function (topic) { return topic.toString(); }),
            args: args,
        });
    };
    MockHubPoolClient.prototype.proposeRootBundle = function (challengePeriodEndTimestamp, poolRebalanceLeafCount, bundleEvaluationBlockNumbers, poolRebalanceRoot, relayerRefundRoot, slowRelayRoot, proposer) {
        var event = "ProposeRootBundle";
        poolRebalanceRoot = poolRebalanceRoot !== null && poolRebalanceRoot !== void 0 ? poolRebalanceRoot : "XX";
        relayerRefundRoot = relayerRefundRoot !== null && relayerRefundRoot !== void 0 ? relayerRefundRoot : "XX";
        slowRelayRoot = slowRelayRoot !== null && slowRelayRoot !== void 0 ? slowRelayRoot : "XX";
        proposer = proposer !== null && proposer !== void 0 ? proposer : randomAddress();
        var topics = [poolRebalanceRoot, relayerRefundRoot, proposer];
        var args = {
            challengePeriodEndTimestamp: challengePeriodEndTimestamp,
            poolRebalanceLeafCount: poolRebalanceLeafCount,
            bundleEvaluationBlockNumbers: bundleEvaluationBlockNumbers,
            poolRebalanceRoot: poolRebalanceRoot,
            relayerRefundRoot: relayerRefundRoot,
            slowRelayRoot: slowRelayRoot,
            proposer: proposer,
        };
        return this.eventManager.generateEvent({
            event: event,
            address: this.hubPool.address,
            topics: topics.map(function (topic) { return topic.toString(); }),
            args: args,
        });
    };
    MockHubPoolClient.prototype.executeRootBundle = function (groupIndex, leafId, chainId, l1Tokens, bundleLpFees, netSendAmounts, runningBalances, caller) {
        var event = "RootBundleExecuted";
        caller = caller !== null && caller !== void 0 ? caller : randomAddress();
        var topics = [leafId, chainId, caller];
        var args = {
            groupIndex: groupIndex,
            leafId: leafId,
            chainId: chainId,
            l1Tokens: l1Tokens,
            bundleLpFees: bundleLpFees,
            netSendAmounts: netSendAmounts,
            runningBalances: runningBalances,
            caller: caller,
        };
        return this.eventManager.generateEvent({
            event: event,
            address: this.hubPool.address,
            topics: topics.map(function (topic) { return topic.toString(); }),
            args: args,
        });
    };
    return MockHubPoolClient;
}(HubPoolClient));
export { MockHubPoolClient };
//# sourceMappingURL=MockHubPoolClient.js.map