import { __awaiter, __generator } from "tslib";
import { getSamplesBetween } from "../../../utils";
import { Web3ErrorCode } from "./model";
var DEFAULT_BLOCK_RANGE = 100000;
/**
 * Class that wraps the queryFilter calls and has the ability to resize the block range
 * in order to comply with the eventual node restrictions in terms of the block range or the
 * length of the response
 */
var SpokePoolEventsQuerier = /** @class */ (function () {
    function SpokePoolEventsQuerier(spokePool, blockRangeSize, logger) {
        this.spokePool = spokePool;
        this.blockRangeSize = blockRangeSize;
        this.logger = logger;
    }
    SpokePoolEventsQuerier.prototype.getFundsDepositEvents = function (from, to, depositorAddr) {
        return this.getEvents(from, to, this.getDepositEventsFilters(depositorAddr));
    };
    SpokePoolEventsQuerier.prototype.getFilledRelayEvents = function (from, to, depositorAddr) {
        return this.getEvents(from, to, this.getFilledRelayEventsFilter(depositorAddr));
    };
    SpokePoolEventsQuerier.prototype.getSpeedUpDepositEvents = function (from, to, depositorAddr) {
        return this.getEvents(from, to, this.getSpeedUpDepositEventsFilter(depositorAddr));
    };
    SpokePoolEventsQuerier.prototype.getFilledRelayEventsFilter = function (depositorAddr) {
        if (depositorAddr) {
            return this.spokePool.filters.FilledRelay(undefined, undefined, undefined, undefined, undefined, undefined, undefined, undefined, undefined, undefined, undefined, depositorAddr, undefined, undefined, undefined);
        }
        return this.spokePool.filters.FilledRelay();
    };
    SpokePoolEventsQuerier.prototype.getDepositEventsFilters = function (depositorAddr) {
        if (depositorAddr) {
            return this.spokePool.filters.FundsDeposited(undefined, undefined, undefined, undefined, undefined, undefined, undefined, undefined, depositorAddr.toLowerCase());
        }
        return this.spokePool.filters.FundsDeposited();
    };
    SpokePoolEventsQuerier.prototype.getSpeedUpDepositEventsFilter = function (depositorAddr) {
        if (depositorAddr) {
            return this.spokePool.filters.RequestedSpeedUpDeposit(undefined, undefined, depositorAddr.toLowerCase(), undefined);
        }
        return this.spokePool.filters.RequestedSpeedUpDeposit();
    };
    SpokePoolEventsQuerier.prototype.getEvents = function (from, to, filters) {
        var _a;
        return __awaiter(this, void 0, void 0, function () {
            var events, retryWithLowerBatchSize, blockRangeSizeAtStart, intervals, _b, intervalStart, intervalEnd, newEvents, newEventsList, newEvents, error_1, newBlockRangeSize;
            var _this = this;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0:
                        events = [];
                        _c.label = 1;
                    case 1:
                        blockRangeSizeAtStart = this.blockRangeSize;
                        _c.label = 2;
                    case 2:
                        _c.trys.push([2, 8, , 9]);
                        retryWithLowerBatchSize = false;
                        events = [];
                        if (!this.blockRangeSize) return [3 /*break*/, 5];
                        intervals = getSamplesBetween(from, to, this.blockRangeSize);
                        _b = intervals[0], intervalStart = _b[0], intervalEnd = _b[1];
                        return [4 /*yield*/, this.spokePool.queryFilter(filters, intervalStart, intervalEnd)];
                    case 3:
                        newEvents = _c.sent();
                        events.push.apply(events, newEvents);
                        return [4 /*yield*/, Promise.all(intervals
                                .slice(1)
                                .map(function (_a) {
                                var intervalStart = _a[0], intervalEnd = _a[1];
                                return _this.spokePool.queryFilter(filters, intervalStart, intervalEnd);
                            }))];
                    case 4:
                        newEventsList = _c.sent();
                        events.push.apply(events, newEventsList.flat());
                        return [3 /*break*/, 7];
                    case 5: return [4 /*yield*/, this.spokePool.queryFilter(filters, from, to)];
                    case 6:
                        newEvents = _c.sent();
                        events.push.apply(events, newEvents);
                        _c.label = 7;
                    case 7: return [3 /*break*/, 9];
                    case 8:
                        error_1 = _c.sent();
                        if (error_1.error.code === Web3ErrorCode.BLOCK_RANGE_TOO_LARGE ||
                            error_1.error.code === Web3ErrorCode.EXCEEDED_MAXIMUM_BLOCK_RANGE) {
                            // make sure the block range size wasn't modified by a parallel function call
                            if (this.blockRangeSize === blockRangeSizeAtStart) {
                                newBlockRangeSize = this.blockRangeSize ? this.blockRangeSize / 2 : DEFAULT_BLOCK_RANGE;
                                (_a = this.logger) === null || _a === void 0 ? void 0 : _a.debug("[SpokePoolEventsQuerier::getEventsInBatches]", "\uD83D\uDD34 lowering block range size from ".concat(this.blockRangeSize, " to ").concat(newBlockRangeSize));
                                this.blockRangeSize = newBlockRangeSize;
                            }
                            retryWithLowerBatchSize = true;
                        }
                        else {
                            retryWithLowerBatchSize = false;
                            console.error(error_1);
                            throw error_1;
                        }
                        return [3 /*break*/, 9];
                    case 9:
                        if (retryWithLowerBatchSize) return [3 /*break*/, 1];
                        _c.label = 10;
                    case 10: return [2 /*return*/, events];
                }
            });
        });
    };
    return SpokePoolEventsQuerier;
}());
export { SpokePoolEventsQuerier };
//# sourceMappingURL=SpokePoolEventsQuerier.js.map