import { CachingMechanismInterface, Deposit, Fill } from "../interfaces";
export declare function shouldCache(eventTimestamp: number, latestTime: number, cachingMaxAge: number): boolean;
/**
 * Calls the cache's get method and returns the result if it is defined, otherwise returns undefined.
 * @param key The key to get from the cache.
 * @param cache The cache to get the key from.
 * @returns The value associated with the key in the cache, or undefined if the key is not in the cache.
 */
export declare function getDepositInCache(key: string, cache: CachingMechanismInterface): Promise<Deposit | undefined>;
export declare function setDepositInCache(deposit: Deposit, currentChainTime: number, cache: CachingMechanismInterface, expirySeconds?: number, timeToCache?: number): Promise<void>;
/**
 * Resolves the key for caching either a deposit or a fill.
 * @param depositOrFill Either a deposit or a fill. In either case, the depositId and originChainId are used to generate the key.
 * @returns The key for caching the deposit or fill.
 */
export declare function getDepositKey(depositOrFill: Deposit | Fill): string;
